@@ -55,14 +55,23 @@ module FactoryGirl
     @configuration = nil
   end
 
-  def self.lint(factories_to_lint = FactoryGirl.factories)
-    Linter.lint!(factories_to_lint)
+  # Look for errors in factories and (optionally) their traits.
+  # Parameters:
+  # factories - which factories to lint; omit for all factories
+  # options:
+  #   traits : true - to lint traits as well as factories
+  def self.lint(*args)
+    options = args.extract_options!
+    factories_to_lint = args[0] || FactoryGirl.factories
+    strategy = options[:traits] ? :factory_and_traits : :factory
+    Linter.new(factories_to_lint, strategy).lint!
   end
 
   class << self
     delegate :factories, :sequences, :traits, :callbacks, :strategies, :callback_names,
-      :to_create, :skip_create, :initialize_with, :constructor, :duplicate_attribute_assignment_from_initialize_with,
-      :duplicate_attribute_assignment_from_initialize_with=, to: :configuration
+      :to_create, :skip_create, :initialize_with, :constructor,
+      :duplicate_attribute_assignment_from_initialize_with, :duplicate_attribute_assignment_from_initialize_with=,
+      :allow_class_lookup, :allow_class_lookup=, to: :configuration
   end
 
   def self.register_factory(factory)
