@@ -89,9 +89,9 @@ module FactoryGirl
     end
 
     def alias_names_to_ignore
-      @attribute_list.non_ignored.map do |attribute|
+      @attribute_list.non_ignored.flat_map do |attribute|
         override_names.map { |override| attribute.name if attribute.alias_for?(override) && attribute.name != override && !ignored_attribute_names.include?(override) }
-      end.flatten.compact
+      end.compact
     end
   end
 end
