@@ -3,6 +3,8 @@ module FactoryGirl
   class Configuration
     attr_reader :factories, :sequences, :traits, :strategies, :callback_names
 
+    attr_accessor :allow_class_lookup
+
     def initialize
       @factories      = Decorator::DisallowsDuplicatesRegistry.new(Registry.new('Factory'))
       @sequences      = Decorator::DisallowsDuplicatesRegistry.new(Registry.new('Sequence'))
@@ -11,6 +13,8 @@ module FactoryGirl
       @callback_names = Set.new
       @definition     = Definition.new
 
+      @allow_class_lookup = true
+
       to_create { |instance| instance.save! }
       initialize_with { new }
     end
