@@ -54,7 +54,7 @@ module FactoryGirl
     def ignore(&block)
       ActiveSupport::Deprecation.warn "`#ignore` is deprecated and will be "\
         "removed in 5.0. Please use `#transient` instead."
-      transient &block
+      transient(&block)
     end
 
     def transient(&block)
@@ -115,7 +115,7 @@ module FactoryGirl
     #   sequence(:email) { |n| "person#{n}@example.com" }
     #
     #   factory :user do
-    #     email { FactoryGirl.create(:email) }
+    #     email { FactoryGirl.generate(:email) }
     #   end
     #
     # Except that no globally available sequence will be defined.
