@@ -10,6 +10,7 @@ module FactoryGirl
       def result(evaluation)
         evaluation.object.tap do |instance|
           stub_database_interaction_on_result(instance)
+          clear_changed_attributes_on_result(instance)
           evaluation.notify(:after_stub, instance)
         end
       end
@@ -44,7 +45,7 @@ module FactoryGirl
             raise "stubbed models are not allowed to access the database - #{self.class.to_s}#connection()"
           end
 
-          def reload
+          def reload(*args)
             raise "stubbed models are not allowed to access the database - #{self.class.to_s}#reload()"
           end
 
@@ -55,6 +56,14 @@ module FactoryGirl
           def update_column(*args)
             raise "stubbed models are not allowed to access the database - #{self.class.to_s}#update_column(#{args.join(",")})"
           end
+
+          def increment!(*args)
+            raise "stubbed models are not allowed to access the database - #{self.class}#increment!(#{args.join(',')})"
+          end
+
+          def decrement!(*args)
+            raise "stubbed models are not allowed to access the database - #{self.class}#decrement!(#{args.join(',')})"
+          end
         end
 
         created_at_missing_default = result_instance.respond_to?(:created_at) && !result_instance.created_at
@@ -68,6 +77,21 @@ module FactoryGirl
           end
         end
       end
+
+      def clear_changed_attributes_on_result(result_instance)
+        unless result_instance.respond_to?(:clear_changes_information)
+          result_instance.extend ActiveModelDirtyBackport
+        end
+
+        result_instance.clear_changes_information
+      end
+    end
+
+    module ActiveModelDirtyBackport
+      def clear_changes_information
+        @previously_changed = ActiveSupport::HashWithIndifferentAccess.new
+        @changed_attributes = ActiveSupport::HashWithIndifferentAccess.new
+      end
     end
   end
 end
